{{ fullname | escape | underline}}

.. testsetup::

   from {{ module }} import {{ objname }}

.. currentmodule:: {{ module }}

.. autoclass:: {{ objname }}
   :members:
   :undoc-members:
   :show-inheritance:
